/* gsl-complex.vapi
 *
 * Copyright (C) 2008  Matias De la Puente
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.

 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 *
 * Author:
 * 	Matias De la Puente <mfpuente.ar@gmail.com>
 */

namespace Gsl
{

	[SimpleType]
	[CCode (cname="gsl_complex", cheader_filename="gsl/gsl_complex.h")]
	public struct GslComplex
	{
		[CCode (cname="dat[0]")]
		public double real;
		[CCode (cname="dat[1]")]
		public double imag;
	}
	
	[CCode (cprefix="gsl_complex_", cheader_filename="gsl/gsl_complex.h,gsl/gsl_complex_math.h")]
	public static class Complex
	{
		public static GslComplex rect (double x, double y);
		public static GslComplex polar (double r, double theta);
		
		// Properties
		public static double arg (GslComplex z);
		public static double abs (GslComplex z);
		public static double abs2 (GslComplex z);
		public static double logabs (GslComplex z);

		// Arithmetic operators
		public static GslComplex add (GslComplex a, GslComplex b);
		public static GslComplex sub (GslComplex a, GslComplex b);
		public static GslComplex mul (GslComplex a, GslComplex b);
		public static GslComplex div (GslComplex a, GslComplex b);
		public static GslComplex add_real (GslComplex a, double x);
		public static GslComplex sub_real (GslComplex a, double x);
		public static GslComplex mul_real (GslComplex a, double x);
		public static GslComplex div_real (GslComplex a, double x);
		public static GslComplex add_imag (GslComplex a, double y);
		public static GslComplex sub_imag (GslComplex a, double y);
		public static GslComplex mul_imag (GslComplex a, double y);
		public static GslComplex div_imag (GslComplex a, double y);
		public static GslComplex conjugate (GslComplex z);
		public static GslComplex inverse (GslComplex z);
		public static GslComplex negative (GslComplex z);
		
		// Elementary functions
		public static GslComplex sqrt (GslComplex z);
		public static GslComplex sqrt_real (double x);
		public static GslComplex pow (GslComplex z, GslComplex a);
		public static GslComplex pow_real (GslComplex z, double x);
		public static GslComplex exp (GslComplex z);
		public static GslComplex log (GslComplex z);
		public static GslComplex log10 (GslComplex z);
		public static GslComplex log_b (GslComplex z, GslComplex b);
		
		// Trigonometric functions
		public static GslComplex sin (GslComplex z);
		public static GslComplex cos (GslComplex z);
		public static GslComplex tan (GslComplex z);
		public static GslComplex sec (GslComplex z);
		public static GslComplex csc (GslComplex z);
		public static GslComplex cot (GslComplex z);
		
		// Inverse trigonometric functions
		public static GslComplex arcsin (GslComplex z);
		public static GslComplex arcsin_real (double z);
		public static GslComplex arccos (GslComplex z);
		public static GslComplex arccos_real (double z);
		public static GslComplex arctan (GslComplex z);
		public static GslComplex arcsec (GslComplex z);
		public static GslComplex arcsec_real (double z);
		public static GslComplex arccsc (GslComplex z);
		public static GslComplex arccsc_real (double z);
		public static GslComplex arccot (GslComplex z);
		
		// Hyperbolic functions
		public static GslComplex sinh (GslComplex z);
		public static GslComplex cosh (GslComplex z);
		public static GslComplex tanh (GslComplex z);
		public static GslComplex sech (GslComplex z);
		public static GslComplex csch (GslComplex z);
		public static GslComplex coth (GslComplex z);
		
		// Inverse hyperbolic functions
		public static GslComplex arcsinh (GslComplex z);
		public static GslComplex arccosh (GslComplex z);
		public static GslComplex arccosh_real (double z);
		public static GslComplex arctanh (GslComplex z);
		public static GslComplex arctanh_real (double z);
		public static GslComplex arcsech (GslComplex z);
		public static GslComplex arccsch (GslComplex z);
		public static GslComplex arccoth (GslComplex z);
	}
}

