/* gsl-stats.vapi
 *
 * Copyright (C) 2008  Matias De la Puente
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.

 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 *
 * Author:
 * 	Matias De la Puente <mfpuente.ar@gmail.com>
 */

namespace Gsl
{
	[CCode (cprefix="gsl_stats_", cheader_filename="gsl/gsl_statistics.h")]
	public static class Stats
	{
		public static double mean (double* data, size_t stride, size_t n);
		public static double variance (double* data, size_t stride, size_t n);
		public static double variance_m (double* data, size_t stride, size_t n, double mean);
		public static double sd (double* data, size_t stride, size_t n);
		public static double sd_m (double* data, size_t stride, size_t n, double mean);
		public static double tss (double* data, size_t stride, size_t n);
		public static double tss_m (double* data, size_t stride, size_t n, double mean);
		public static double variance_with_fixed_mean (double* data, size_t stride, size_t n, double mean);
		public static double sd_with_fixed_mean (double* data, size_t stride, size_t n, double mean);
		public static double absdev (double* data, size_t stride, size_t n);
		public static double absdev_m (double* data, size_t stride, size_t n, double mean);
		public static double skew (double* data, size_t stride, size_t n);
		public static double skew_m_sd (double* data, size_t stride, size_t n, double mean, double sd);
		public static double kurtosis (double* data, size_t stride, size_t n);
		public static double kurtosis_m_sd (double* data, size_t stride, size_t n, double mean, double sd);
		public static double lag1_autocorrelation (double* data, size_t stride, size_t n);
		public static double lag1_autocorrelation_m (double* data, size_t stride, size_t n, double mean);
		public static double covariance (double* data1, size_t stride1, double* data2, size_t stride2, size_t n);
		public static double covariance_m (double* data1, size_t stride1, double* data2, size_t stride2, size_t n, double mean1, double mean2);
		public static double correlation (double* data1, size_t stride1, double* data2, size_t stride2, size_t n);
		
		public static double wmean (double* w, size_t wstride, double* data, size_t stride, size_t n);
		public static double wvariance (double* w, size_t wstride, double* data, size_t stride, size_t n);
		public static double wvariance_m (double* w, size_t wstride, double* data, size_t stride, size_t n, double wmean);
		public static double wsd (double* w, size_t wstride, double* data, size_t stride, size_t n);
		public static double wsd_m (double* w, size_t wstride, double* data, size_t stride, size_t n, double wmean);
		public static double wtss (double* w, size_t wstride, double* data, size_t stride, size_t n);
		public static double wtss_m (double* w, size_t wstride, double* data, size_t stride, size_t n, double mean);
		public static double wvariance_with_fixed_mean (double* w, size_t wstride, double* data, size_t stride, size_t n, double wmean);
		public static double wsd_with_fixed_mean (double* w, size_t wstride, double* data, size_t stride, size_t n, double wmean);
		public static double wabsdev (double* w, size_t wstride, double* data, size_t stride, size_t n);
		public static double wabsdev_m (double* w, size_t wstride, double* data, size_t stride, size_t n, double wmean);
		public static double wskew (double* w, size_t wstride, double* data, size_t stride, size_t n);
		public static double wskew_m_sd (double* w, size_t wstride, double* data, size_t stride, size_t n, double wmean, double wsd);
		public static double wkurtosis (double* w, size_t wstride, double* data, size_t stride, size_t n);
		public static double wkurtosis_m_sd (double* w, size_t wstride, double* data, size_t stride, size_t n, double wmean, double wsd);
		
		public static double max (double* data, size_t stride, size_t n);
		public static double min (double* data, size_t stride, size_t n);
		public static void minmax (out double min, out double max, double* data, size_t stride, size_t n);
		public static size_t max_index (double* data, size_t stride, size_t n);
		public static size_t min_index (double* data, size_t stride, size_t n);
		public static void minmax_index (out size_t min, out size_t max, double* data, size_t stride, size_t n);
		
		public static double median_from_sorted_data (double* sorted_data, size_t stride, size_t n);
		public static double quantile_from_sorted_data (double* sorted_data, size_t stride, size_t n, double f);
	}
}

